@@ -1,5 +1,5 @@
 from typing import List, Optional
-from schema import PlayerMove, Player
+from .schema import PlayerMove, Player
 
 
 class LogWriter:
