@@ -16,13 +16,13 @@ app = typer.Typer()
 def play_game(
     player1_url: str = typer.Argument(...,
                                       help="The url of the bot for player 1"),
-    player2_url: str = typer.Argument(...,
-                                      help="The url of the bot for player 2"),
+    player0_url: str = typer.Argument(...,
+                                      help="The url of the bot for player 0"),
     log_file: str = typer.Argument(default="./logs/local",
                                    help="The path to which log file should be written"),
     verbose: bool = typer.Argument(
         default=False, help="Whether to print out board states and moves when running simulator"),
-    simulation_logs_level: bool = typer.Argument(default=logging.WARNING,
+    simulation_logs_level: int = typer.Argument(default=logging.WARNING,
                                                  help="Logs level for simulator logs", show_default=True)
 ) -> GameResult:
     """
@@ -36,15 +36,15 @@ def play_game(
         verbose=verbose, logging_level=simulation_logs_level)
     try:
         logger.info(
-            f"Starting simulation of game for bot1: {player1_url}, bot2: {player2_url}")
-        winner = game_simulator.run([player1_url, player2_url],
+            f"Starting simulation of game for bot1: {player1_url}, bot2: {player0_url}")
+        winner = game_simulator.run([player1_url, player0_url],
                                     bot_data=bot_data, player_moves=player_moves)
         logger.info(
             "Game successfully completed. Writing game moves to log file")
         log_writer = LogWriter(
             path=log_file, player_moves=player_moves, winner=winner)
         log_writer.write()
-        result = GameResult.PLAYER1_WINS if winner == Player.BLUE else GameResult.PLAYER2_WINS
+        result = GameResult.PLAYER1_WINS if winner == Player.BLUE else GameResult.PLAYER0_WINS
         logger.info(f"Game completed. Result: {result}")
         return result
     except (InvalidMovesException, TimeoutException) as ex:
@@ -55,7 +55,7 @@ def play_game(
         log_writer = LogWriter(
             path=log_file, player_moves=player_moves, error_message=ex.message)
         log_writer.write()
-        result = GameResult.PLAYER1_WINS if ex.player == Player.RED else GameResult.PLAYER2_WINS
+        result = GameResult.PLAYER1_WINS if ex.player == Player.RED else GameResult.PLAYER0_WINS
         logger.info(f"Game Completed. Result: {result}")
         return result
     except MovesExceededException as ex:
